{ config, pkgs, ... }:
{
  services.xserver.enable = true;
  services.xserver.displayManager.gdm.enable = true;
  services.xserver.displayManager.gdm.wayland = true;
  services.xserver.desktopManager.gnome.enable = true;
  #services.printing.enable = true; # CUPS
  programs.xwayland.enable = true;
  xdg.portal.enable = true;

  services.udev.packages = with pkgs; [ gnome.gnome-settings-daemon ];

  programs.gnome-terminal.enable = false;

  services.tumbler.enable = true; # TODO: needed when we have ffmpegthumbnailer?
  services.gnome.sushi.enable = true;
  services.gnome.gnome-online-accounts.enable = true;

  services.gnome.gnome-browser-connector.enable  = true;

  environment.systemPackages = with pkgs; [
    firefox
    pavucontrol
    lxterminal
    gnome.gnome-tweaks
    # TODO: shadow gnome-terminal
    ffmpegthumbnailer
    libheif # HEIF thumbnails
    gnomeExtensions.appindicator

    loupe

    desktop-file-utils # update-desktop-database
  ];

  # an attempt to make nautilus discover new files, but it proved to be a freebsd-linux incompatiblity
  # inotify is a linux thing, and freebsd instead features kqueue.
  # nfs likely doesn't support such events anyway, predating inotify.
  #kernel.sysctl = {
  #  "fs.inotify.max_user_watches" = "100000";
  #};
  # possible future fix:
  # https://en.wikipedia.org/wiki/File_Alteration_Monitor
  # or https://github.com/fsnotify/fsnotify

  environment.gnome.excludePackages = (with pkgs; [
    gnome-photos
    gnome-tour
    (pkgs.gedit or pkgs.gnome.gedit) # text editor (24.05 vs 23.11)
    papers # Document Viewer (new)
  ]) ++ (with pkgs.gnome; [
    eog
    #cheese # webcam tool
    simple-scan # scanning utility
    yelp # Help
    #baobab # Disk Usage Analyser
    evince # Document Viewer
    gnome-music
    gnome-terminal
    epiphany # web browser
    geary # email reader
    totem # video player
    tali # poker game
    iagno # go game
    hitori # sudoku game
    atomix # puzzle game
  ]);
}
